#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include <asm/page.h>

#include "psplash-fb.h"
#include "mp-cursors.h"
#include  "lcd.h"

#define TRUE 1
#define FALSE 0
#define MAX(x,y) ((x)>(y)?(x):(y))
#define MIN(x,y) ((x)<(y)?(x):(y))

#define PAGE_SHIFT      12
#define PAGE_SIZE       (1UL << PAGE_SHIFT)
#define PAGE_MASK       (~(PAGE_SIZE-1))

#define SET_OSD_INFO    _IOW('F', 209, s3c_win_info_t)
#define SET_OSD_START   _IO('F', 201)
#define SET_OSD_STOP	_IO('F', 202)
#define S3C_FB_RELEASE_DEFAULT_FB       _IO  ('F', 322)

typedef unsigned char guint8;
static PSplashFB *fb = NULL;

static void
_set_color_key_params()
{
    s3c_color_key_info_t color_key;
    s3c_color_val_info_t color_value;
    int ret = -1;

    color_key.direction = S3C_FB_COLOR_KEY_DIR_BG;
    color_key.compkey_red = 0x00;
    color_key.compkey_green = 0x00;
    color_key.compkey_blue = 0x00;

    color_value.colval_red = 0x00;
    color_value.colval_green = 0x00;
    color_value.colval_blue = 0x00;

    ret = ioctl(fb->fd, S3C_FB_COLOR_KEY_SET_INFO, &color_key);
    printf("color key set info ret=%d\n", ret);

    ret = ioctl(fb->fd, S3C_FB_COLOR_KEY_VALUE, &color_value);
    printf("color value ret=%d\n", ret);

    ret = ioctl (fb->fd, S3C_FB_COLOR_KEY_START);
    printf("color key start ret=%d\n", ret);

//    ret = ioctl (fb->fd, S3C_FB_COLOR_KEY_ALPHA_START);
    printf("color key alpha start ret=%d\n", ret);
}

int main(int argc, char ** argv)
{
    s3c_win_info_t  osd_info_to_driver;

    printf("\nuseage : fb-test /dev/fbX x y width height\n");
    if ((fb = psplash_fb_new(argv[1])) == NULL)
        exit(-1);

    osd_info_to_driver.Bpp          = 16;
    osd_info_to_driver.LeftTop_x    = atoi(argv[2]);
    osd_info_to_driver.LeftTop_y    = atoi(argv[3]);
    osd_info_to_driver.Width        = atoi(argv[4]);        // display width
    osd_info_to_driver.Height       = atoi(argv[5]);       // display height

//  ioctl (fb->fd, SET_OSD_STOP);

    if(ioctl(fb->fd, SET_OSD_INFO, &osd_info_to_driver)) 
    {
        printf("Some problem with the ioctl SET_OSD_INFO\n");
        return -1;
    }

//    ioctl(fb->fd, S3C_FB_RELEASE_DEFAULT_FB);
//    psplash_fb_draw_rect (fb, 0, 0, 800, 480, 0xff, 0xff, 0xff);
    psplash_fb_draw_rect (fb, atoi(argv[2]), atoi(argv[3]), atoi(argv[4]), atoi(argv[5]), 0xff, 0xff, 0xff);

    psplash_fb_draw_image (fb,
        0,0,
        MP_CURSORS_WIDTH,
        MP_CURSORS_HEIGHT,
        MP_CURSORS_BYTES_PER_PIXEL,
        MP_CURSORS_RLE_PIXEL_DATA);

//    _set_color_key_params();
    ioctl(fb->fd, SET_OSD_START);
    
    printf("set osd start\n");
    psplash_fb_destroy (fb);
    
    return 0;
}
